[![CI](https://gitlab.desy.de/jannis.necker/timewise_sup/badges/main/pipeline.svg)](https://gitlab.desy.de/jannis.necker/timewise_sup/-/commits/main)
[![coverage](https://jannisnecker.pages.desy.de/timewise_sup/badges/coverage.svg)](https://jannisnecker.pages.desy.de/timewise_sup/coverage/)
[![pylint](https://jannisnecker.pages.desy.de/timewise_sup/badges/pylint.svg)](https://jannisnecker.pages.desy.de/timewise_sup/lint/)
[![docs](https://jannisnecker.pages.desy.de/timewise_sup/badges/docs.svg)](https://jannisnecker.pages.desy.de/timewise_sup/docs/)
[![mypy](https://www.mypy-lang.org/static/mypy_badge.svg)](http://mypy-lang.org/)
[![pypi](https://badge.fury.io/py/timewise-sup.svg)](https://pypi.org/project/timewise-sup/)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.8253038.svg)](https://doi.org/10.5281/zenodo.8253038)

![](docs/source/timewise_sup.png)
# The Timewise Subtraction Pipeline

The Timewise Subtraction Pipeline is a tool to build difference lightcurves from WISE data. It is based on the [timewise](
https://github.com/JannisNe/timewise) package. Please find detailed documentation 
[here](https://jannisnecker.pages.desy.de/timewise_sup/docs).

